# -*- coding: utf-8 -*-

from django.template import Context, Template
from django.test import TestCase, RequestFactory

class NavhelperTemplateTagTests(TestCase):
    def setUp(self):
        self.factory = RequestFactory()

    def test_navactive(self):
        self._navactive_common('active', '')

        with self.settings(NAVHELPER_ACTIVE_CLASS='my-active-class',
                NAVHELPER_NOT_ACTIVE_CLASS='my-not-active-class'):
            self._navactive_common('my-active-class', 'my-not-active-class')

    def test_renavactive(self):
        self._renavactive_common('active', '')

        with self.settings(NAVHELPER_ACTIVE_CLASS='my-active-class',
                NAVHELPER_NOT_ACTIVE_CLASS='my-not-active-class'):
            self._renavactive_common('my-active-class', 'my-not-active-class')

    def _navactive_common(self, active, not_active):
        request = self.factory.get('/main-page/')

        out = Template(
                "{% load navactive %}"
                "{% navactive request 'p1' %}"
            ).render(Context({"request": request}))
        self.assertEqual(out, active)

        out = Template(
                "{% load navactive %}"
                "{% navactive request 'p1-s1' %}"
            ).render(Context({"request": request}))
        self.assertEqual(out, not_active)

        out = Template(
                "{% load navactive %}"
                "{% navactive request 'p1 p1-s1' %}"
            ).render(Context({"request": request}))
        self.assertEqual(out, active)

        out = Template(
                "{% load navactive %}"
                "{% navactive request 'p2' %}"
            ).render(Context({"request": request}))
        self.assertEqual(out, not_active)

    def _renavactive_common(self, active, not_active):
        t1 = "{% load navactive %}{% renavactive request '^/main-page' %}"

        request = self.factory.get('/main-page/')
        out = Template(t1).render(Context({"request": request}))
        self.assertEqual(out, active)

        request = self.factory.get('/main-page/sub-section/')
        out = Template(t1).render(Context({"request": request}))
        self.assertEqual(out, active)

        request = self.factory.get('/second-page/')
        out = Template(t1).render(Context({"request": request}))
        self.assertEqual(out, not_active)



from django.template import Library
from django.urls import resolve
from django.conf import settings
import re

register = Library()


@register.simple_tag
def renavactive(request, pattern):
    """
    {% renavactive request "^/a_regex" %}
    """
    if re.search(pattern, request.path):
        return getattr(settings, "NAVHELPER_ACTIVE_CLASS", "active")
    return getattr(settings, "NAVHELPER_NOT_ACTIVE_CLASS", "")


@register.simple_tag
def navactive(request, urls):
    """
    {% navactive request "view_name another_view_name" %}
    """
    url_list = set(urls.split())

    resolved = resolve(request.path)
    resolved_urls = set()
    if resolved.url_name:
        resolved_urls.add(resolved.url_name)
    if resolved.namespaces:
        resolved_urls = resolved_urls.union(["{}:{}".format(namespace, resolved.url_name) for namespace in resolved.namespaces])
        resolved_urls = resolved_urls.union(["{}:".format(namespace) for namespace in resolved.namespaces])
    if getattr(resolved, 'app_name', None):
        resolved_urls = resolved_urls.union(["{}:{}".format(resolved.app_name, resolved.url_name), "{}:".format(resolved.app_name)])
    if getattr(resolved, 'app_names', []):
        resolved_urls = resolved_urls.union(["{}:{}".format(app_name, resolved.url_name) for app_name in resolved.app_names])
        resolved_urls = resolved_urls.union(["{}:".format(app_name) for app_name in resolved.app_names])
    if url_list and resolved_urls and bool(resolved_urls & url_list):
        return getattr(settings, "NAVHELPER_ACTIVE_CLASS", "active")
    return getattr(settings, "NAVHELPER_NOT_ACTIVE_CLASS", "")





DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': ':memory:',
    },
}

INSTALLED_APPS = [
    "geelweb.django.navhelper",
    "tests",
]

SITE_ID = 1

SECRET_KEY = 'sfbysvgcizvncwhf89'

MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.contrib.flatpages.middleware.FlatpageFallbackMiddleware',
)

ROOT_URLCONF = 'tests.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
    }
]
